@@ -8,10 +8,8 @@ from cngi.dio import read_vis
 #    import time
 
 deg_to_rad = np.pi/180
-from sirius import make_ant_sky_jones, simulation
-from sirius._sirius_utils._math_utils import _compute_rot_coords
-from sirius._sirius_utils._calc_parallactic_angles import _calc_parallactic_angles, _find_optimal_set_angle
-from sirius._sirius_utils._math_utils import _rot_coord
+from sirius import calc_beam, simulation
+from sirius._sirius_utils._coord_transforms import _compute_rot_coords, _rot_coord
 from astropy.time import Time
 from astropy.coordinates import (EarthLocation, SkyCoord, AltAz, CIRS)
 import astropy.units as u
@@ -107,4 +105,4 @@ def test_simulation():
     uvw_import = np.load("data/test_data/simulation_test/uvw_test.npy")"""
     
     #assert (np.allclose(vis_data, vis_data_import), np.allclose(uvw, uvw_import)) == (True, True)
-    assert True
\ No newline at end of file
+    assert True
